### Name: opt.RW.Mult
### Title: Functions to analyze multiple time-series jointly
### Aliases: opt.RW.Mult logL.Mult logL.SameMs logL.SameVs opt.RW.SameMs
###   opt.RW.SameVs
### Keywords: models ts

### ** Examples

 ## create two sequences, with different parameter values
 y1<- sim.GRW(ns=20, ms=0, vs=1)
 y2<- sim.GRW(ns=20, ms=0, vs=0.2)

 ## fit some models with at least some shared dynamics across sequences
 m1<- opt.RW.Mult(list(y1,y2), model="GRW")
 m2<- opt.RW.SameMs(list(y1, y2))
 m3<- opt.RW.SameVs(list(y1,y2))

 ## fit separate models to each sequence
 msep1<- opt.GRW(y1)
 msep2<- opt.GRW(y2)
 sep.logL<- msep1$value + msep2$value   # total logL sums across two solutions
 sep.aic <- -2*sep.logL + 2*4     # AIC of separate solutions

 ## check out resulting log-likelihoods and AIC values
 mres<- array(dim=c(4,2))
 row.names(mres)<- c("m1", "m2", "m3", "msep")
 colnames(mres)<- c("logL", "AIC")
 mres[1,]<- c(m1$value, m1$AIC)
 mres[2,]<- c(m2$value, m2$AIC)
 mres[3,]<- c(m3$value, m3$AIC)
 mres[4,]<- c(sep.logL, sep.aic)
 print (mres)



